usr/src/uts/common/fs/zfs/zio.c
changeset 9722 e3866bad4e96
parent 9470 6d827468d7b5
child 9725 0bf7402e8022
--- a/usr/src/uts/common/fs/zfs/zio.c	Tue May 26 10:40:43 2009 -0400
+++ b/usr/src/uts/common/fs/zfs/zio.c	Tue May 26 10:05:28 2009 -0700
@@ -942,11 +942,11 @@
 	zio_type_t t = zio->io_type;
 
 	/*
 	 * If we're a config writer, the normal issue and interrupt threads
 	 * may all be blocked waiting for the config lock.  In this case,
 	 * select the otherwise-unused taskq for ZIO_TYPE_NULL.
 	 */
-	if (zio->io_flags & ZIO_FLAG_CONFIG_WRITER)
+	if (zio->io_flags & (ZIO_FLAG_CONFIG_WRITER | ZIO_FLAG_PROBE))
 		t = ZIO_TYPE_NULL;
 
 	/*
@@ -942,11 +942,11 @@
 
 	/*
-	 * If we're a config writer, the normal issue and interrupt threads
-	 * may all be blocked waiting for the config lock.  In this case,
-	 * select the otherwise-unused taskq for ZIO_TYPE_NULL.
+	 * If we're a config writer or a probe, the normal issue and
+	 * interrupt threads may all be blocked waiting for the config lock.
+	 * In this case, select the otherwise-unused taskq for ZIO_TYPE_NULL.
 	 */